# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: robot_controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='robot_controller.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16robot_controller.proto\x12\x06robotc\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0emessages.proto\"+\n\x0bSignalValue\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\"8\n\x0cSignalResult\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\x12\n\n\x02ok\x18\x03 \x01(\x08\"\x1d\n\nSignalList\x12\x0f\n\x07indexes\x18\x01 \x03(\x05\"\xf8\x04\n\tRobotData\x12$\n\trobotMode\x18\x01 \x01(\x0b\x32\x11.robotc.RobotMode\x12%\n\njointModes\x18\x02 \x03(\x0b\x32\x11.robotc.JointMode\x12\"\n\x0b\x61\x63tualJoint\x18\x03 \x01(\x0b\x32\r.robotc.Joint\x12\'\n\x10\x61\x63tualJointSpeed\x18\x04 \x01(\x0b\x32\r.robotc.Joint\x12\"\n\x0btargetJoint\x18\x05 \x01(\x0b\x32\r.robotc.Joint\x12\'\n\x10targetJointSpeed\x18\x06 \x01(\x0b\x32\r.robotc.Joint\x12%\n\ractualTcpPose\x18\x07 \x01(\x0b\x32\x0e.robotc.Vector\x12&\n\x0e\x61\x63tualTcpSpeed\x18\x08 \x01(\x0b\x32\x0e.robotc.Vector\x12%\n\rtargetTcpPose\x18\t \x01(\x0b\x32\x0e.robotc.Vector\x12&\n\x0etargetTcpSpeed\x18\n \x01(\x0b\x32\x0e.robotc.Vector\x12%\n\ncurrentCmd\x18\x0b \x01(\x0b\x32\x11.robotc.CmdStatus\x12\x16\n\x02io\x18\x0c \x01(\x0b\x32\n.robotc.IO\x12\x16\n\x0evelocityFactor\x18\r \x01(\x01\x12\"\n\x08\x63lawInfo\x18\x0e \x01(\x0b\x32\x10.robotc.ClawInfo\x12!\n\njointTemps\x18\x0f \x01(\x0b\x32\r.robotc.Joint\x12#\n\x0ctargetTorque\x18\x10 \x01(\x0b\x32\r.robotc.Joint\x12#\n\x0c\x61\x63tualTorque\x18\x11 \x01(\x0b\x32\r.robotc.Joint\"\x0e\n\x0cRobotDataCmd\"\x87\x02\n\x0eRobotBriefData\x12$\n\trobotMode\x18\x01 \x01(\x0b\x32\x11.robotc.RobotMode\x12\"\n\x0b\x61\x63tualJoint\x18\x02 \x01(\x0b\x32\r.robotc.Joint\x12\"\n\x0btargetJoint\x18\x03 \x01(\x0b\x32\r.robotc.Joint\x12%\n\ractualTcpPose\x18\x04 \x01(\x0b\x32\x0e.robotc.Vector\x12%\n\rtargetTcpPose\x18\x05 \x01(\x0b\x32\x0e.robotc.Vector\x12\x16\n\x0evelocityFactor\x18\x06 \x01(\x01\x12!\n\njointTemps\x18\x07 \x01(\x0b\x32\r.robotc.Joint\"\x19\n\tRobotMode\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"8\n\x02\x44H\x12\t\n\x01\x64\x18\x01 \x01(\x01\x12\t\n\x01\x61\x18\x02 \x01(\x01\x12\r\n\x05\x61lpha\x18\x03 \x01(\x01\x12\r\n\x05theta\x18\x04 \x01(\x01\"\'\n\x07KDParam\x12\x1c\n\x08\x64hParams\x18\x01 \x03(\x0b\x32\n.robotc.DH\"\x19\n\tJointMode\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"\x1e\n\tAmplitude\x12\x11\n\tamplitude\x18\x01 \x01(\x01\"\x19\n\x06HoldOn\x12\x0f\n\x07hold_on\x18\x01 \x01(\x05\"\x16\n\x05\x46orce\x12\r\n\x05\x66orce\x18\x01 \x01(\x01\"\x18\n\x06Weight\x12\x0e\n\x06weight\x18\x01 \x01(\x01\"M\n\x08\x43lawInfo\x12\x11\n\tamplitude\x18\x01 \x01(\x01\x12\r\n\x05\x66orce\x18\x02 \x01(\x01\x12\x0e\n\x06weight\x18\x03 \x01(\x01\x12\x0f\n\x07hold_on\x18\x04 \x01(\x05\"\"\n\x0b\x46orceTorque\x12\x13\n\x0b\x66orceTorque\x18\x01 \x03(\x01\"\x17\n\x05Joint\x12\x0e\n\x06joints\x18\x01 \x03(\x01\"\x18\n\x06Vector\x12\x0e\n\x06vector\x18\x01 \x03(\x01\"\x1d\n\x0bTemperature\x12\x0e\n\x06\x64\x65gree\x18\x01 \x01(\x01\"\x1a\n\x07\x43urrent\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x01\"\x17\n\x06\x46\x61\x63tor\x12\r\n\x05value\x18\x01 \x01(\x01\"\x12\n\x03Ret\x12\x0b\n\x03ret\x18\x01 \x01(\x08\"\x13\n\x05\x43mdId\x12\n\n\x02id\x18\x01 \x01(\x05\"&\n\tCmdStatus\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\"\x1b\n\nIntRequest\x12\r\n\x05index\x18\x01 \x01(\x05\" \n\x04Logs\x12\x18\n\x03log\x18\x01 \x03(\x0b\x32\x0b.robotc.Log\"/\n\x03Log\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\"\x1c\n\x0cSleepRequest\x12\x0c\n\x04time\x18\x01 \x01(\x05\"H\n\rSpeedJRequest\x12\x13\n\x0bjoint_speed\x18\x01 \x03(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x01\x12\x0c\n\x04time\x18\x03 \x01(\x01\"d\n\rSpeedLRequest\x12\x10\n\x08velocity\x18\x01 \x03(\x01\x12\x1d\n\x15position_acceleration\x18\x02 \x01(\x01\x12\x0c\n\x04time\x18\x03 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x01\"$\n\x0cStopJRequest\x12\x14\n\x0c\x64\x65\x63\x65leration\x18\x01 \x01(\x01\"C\n\x0cStopLRequest\x12\x1d\n\x15position_deceleration\x18\x01 \x01(\x01\x12\x14\n\x0c\x64\x65\x63\x65leration\x18\x02 \x01(\x01\"\xec\x01\n\x0cMoveCRequest\x12\x10\n\x08pose_via\x18\x01 \x03(\x01\x12\x0f\n\x07pose_to\x18\x02 \x03(\x01\x12\x19\n\x11pose_via_is_joint\x18\x03 \x01(\x08\x12\x18\n\x10pose_to_is_joint\x18\x04 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x05 \x01(\x01\x12\x10\n\x08velocity\x18\x06 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x07 \x01(\x01\x12\x0c\n\x04mode\x18\x08 \x01(\x05\x12\x0c\n\x04time\x18\t \x01(\x01\x12\x1d\n\tpose_base\x18\n \x01(\x0b\x32\n.robotc.PR\x12\x0b\n\x03rad\x18\x0b \x01(\x01\"\xad\x01\n\x0cMoveJRequest\x12\x15\n\rjoint_pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x0c\n\x04time\x18\x05 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x06 \x01(\x01\x12\x1d\n\tpose_base\x18\x07 \x01(\x0b\x32\n.robotc.PR\"\xa7\x01\n\x0cMoveLRequest\x12\x0f\n\x07pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x0c\n\x04time\x18\x05 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x06 \x01(\x01\x12\x1d\n\tpose_base\x18\x07 \x01(\x0b\x32\n.robotc.PR\"n\n\x0fMoveLRPYRequest\x12\x0f\n\x07pose_to\x18\x01 \x03(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x01\x12\x10\n\x08velocity\x18\x03 \x01(\x01\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x05 \x01(\x01\"z\n\x0cMovePRequest\x12\x0f\n\x07pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x05 \x01(\x01\"{\n\rServoCRequest\x12\x0f\n\x07pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x05 \x01(\x01\"\xa0\x01\n\rServoJRequest\x12\x15\n\rjoint_pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x0c\n\x04time\x18\x05 \x01(\x01\x12\x17\n\x0flook_ahead_time\x18\x06 \x01(\x01\x12\x0c\n\x04gain\x18\x07 \x01(\x05\"_\n\nFineTuning\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x05\x12\x12\n\ncoordinate\x18\x03 \x01(\x05\x12\x0e\n\x06target\x18\x04 \x01(\x05\x12\x11\n\tdirection\x18\x05 \x01(\x05\"7\n\tLEDStatus\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\r\n\x05speed\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x03(\x05\",\n\x0bVoiceStatus\x12\r\n\x05voice\x18\x01 \x01(\x05\x12\x0e\n\x06volume\x18\x02 \x01(\x05\"\x18\n\tFanStatus\x12\x0b\n\x03\x66\x61n\x18\x01 \x01(\x05\":\n\x0c\x43\x61lcTcpParam\x12\x1d\n\x05poses\x18\x01 \x03(\x0b\x32\x0e.robotc.Vector\x12\x0b\n\x03tol\x18\x02 \x01(\x01\"o\n\tLuaStatus\x12\x1f\n\x05state\x18\x01 \x01(\x0e\x32\x10.robotc.LuaState\x12\x1d\n\tlast_pose\x18\x02 \x01(\x0b\x32\n.robotc.PR\x12\"\n\x0blast_joints\x18\x03 \x01(\x0b\x32\r.robotc.JPose\"p\n\nLampStatus\x12\x1e\n\x03led\x18\x01 \x01(\x0b\x32\x11.robotc.LEDStatus\x12\"\n\x05voice\x18\x02 \x01(\x0b\x32\x13.robotc.VoiceStatus\x12\x1e\n\x03\x66\x61n\x18\x03 \x01(\x0b\x32\x11.robotc.FanStatus\"B\n\x0bPVATRequest\x12\x10\n\x08\x64uration\x18\x01 \x01(\x01\x12\t\n\x01q\x18\x02 \x03(\x01\x12\t\n\x01v\x18\x03 \x03(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x04 \x03(\x01\"&\n\x0b\x45xternalPin\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\"7\n\x0c\x45xternalPins\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\"9\n\x0f\x45xternalDigital\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x05\"K\n\x10\x45xternalDigitals\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\"8\n\x0e\x45xternalAnalog\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x01\"J\n\x0f\x45xternalAnalogs\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x01\"\x1c\n\x0e\x45xternalDevice\x12\n\n\x02id\x18\x01 \x01(\x05\"\xa3\x01\n\x0b\x45xternalIOs\x12$\n\x03\x64is\x18\x01 \x03(\x0b\x32\x17.robotc.ExternalDigital\x12$\n\x03\x64os\x18\x02 \x03(\x0b\x32\x17.robotc.ExternalDigital\x12#\n\x03\x61is\x18\x03 \x03(\x0b\x32\x16.robotc.ExternalAnalog\x12#\n\x03\x61os\x18\x04 \x03(\x0b\x32\x16.robotc.ExternalAnalog2\xce-\n\x0fRobotController\x12\x32\n\tPowerDown\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12,\n\x05Sleep\x12\x14.robotc.SleepRequest\x1a\r.robotc.CmdId\x12-\n\x04Sync\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x32\n\tTeachMode\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x35\n\x0c\x45ndTeachMode\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x32\n\x11SetVelocityFactor\x12\x0e.robotc.Factor\x1a\r.robotc.CmdId\x12;\n\x11GetVelocityFactor\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Factor\x12/\n\nSetGravity\x12\x12.robotc.Coordinate\x1a\r.robotc.CmdId\x12\x38\n\nGetGravity\x12\x16.google.protobuf.Empty\x1a\x12.robotc.Coordinate\x12,\n\nSetPayload\x12\x0f.robotc.Payload\x1a\r.robotc.CmdId\x12\x35\n\nGetPayload\x12\x16.google.protobuf.Empty\x1a\x0f.robotc.Payload\x12\x34\n\x0eSetPayloadMass\x12\x13.robotc.PayloadMass\x1a\r.robotc.CmdId\x12=\n\x0eGetPayloadMass\x12\x16.google.protobuf.Empty\x1a\x13.robotc.PayloadMass\x12\x32\n\rSetPayloadCog\x12\x12.robotc.PayloadCog\x1a\r.robotc.CmdId\x12;\n\rGetPayloadCog\x12\x16.google.protobuf.Empty\x1a\x12.robotc.PayloadCog\x12#\n\x06SetTcp\x12\n.robotc.PR\x1a\r.robotc.CmdId\x12,\n\x06GetTcp\x12\x16.google.protobuf.Empty\x1a\n.robotc.PR\x12\x34\n\x10SetClawAmplitude\x12\x11.robotc.Amplitude\x1a\r.robotc.CmdId\x12=\n\x10GetClawAmplitude\x12\x16.google.protobuf.Empty\x1a\x11.robotc.Amplitude\x12\x37\n\rGetClawHoldOn\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.HoldOn\x12,\n\x0cSetClawForce\x12\r.robotc.Force\x1a\r.robotc.CmdId\x12\x37\n\rGetClawWeight\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Weight\x12:\n\x0bGetTcpForce\x12\x16.google.protobuf.Empty\x1a\x13.robotc.ForceTorque\x12-\n\x07SetClaw\x12\x10.robotc.ClawInfo\x1a\x10.robotc.ClawInfo\x12\x33\n\x07GetClaw\x12\x16.google.protobuf.Empty\x1a\x10.robotc.ClawInfo\x12&\n\x06SetPos\x12\r.robotc.JPose\x1a\r.robotc.CmdId\x12.\n\x06SpeedJ\x12\x15.robotc.SpeedJRequest\x1a\r.robotc.CmdId\x12.\n\x06SpeedL\x12\x15.robotc.SpeedLRequest\x1a\r.robotc.CmdId\x12,\n\x05StopJ\x12\x14.robotc.StopJRequest\x1a\r.robotc.CmdId\x12,\n\x05StopL\x12\x14.robotc.StopLRequest\x1a\r.robotc.CmdId\x12\x31\n\x08StopMove\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12,\n\x05MoveC\x12\x14.robotc.MoveCRequest\x1a\r.robotc.CmdId\x12,\n\x05MoveJ\x12\x14.robotc.MoveJRequest\x1a\r.robotc.CmdId\x12,\n\x05MoveL\x12\x14.robotc.MoveLRequest\x1a\r.robotc.CmdId\x12-\n\x06MoveLJ\x12\x14.robotc.MoveLRequest\x1a\r.robotc.CmdId\x12,\n\x05MoveP\x12\x14.robotc.MovePRequest\x1a\r.robotc.CmdId\x12,\n\x06MovePT\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId\x12\x34\n\x0cMovePTStream\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId(\x01\x12-\n\x07MovePVT\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId\x12\x35\n\rMovePVTStream\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId(\x01\x12.\n\x08MovePVAT\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId\x12\x36\n\x0eMovePVATStream\x12\x13.robotc.PVATRequest\x1a\r.robotc.CmdId(\x01\x12.\n\x06ServoC\x12\x15.robotc.ServoCRequest\x1a\r.robotc.CmdId\x12.\n\x06ServoJ\x12\x15.robotc.ServoJRequest\x1a\r.robotc.CmdId\x12\x39\n\x0cGetRobotData\x12\x16.google.protobuf.Empty\x1a\x11.robotc.RobotData\x12\x45\n\x11GetRobotBriefData\x12\x14.robotc.RobotDataCmd\x1a\x16.robotc.RobotBriefData(\x01\x30\x01\x12\x36\n\x0eGetRobotIOData\x12\x14.robotc.RobotDataCmd\x1a\n.robotc.IO(\x01\x30\x01\x12\x39\n\x0cGetRobotMode\x12\x16.google.protobuf.Empty\x1a\x11.robotc.RobotMode\x12@\n\x17GetActualJointPositions\x12\x16.google.protobuf.Empty\x1a\r.robotc.Joint\x12@\n\x17GetTargetJointPositions\x12\x16.google.protobuf.Empty\x1a\r.robotc.Joint\x12=\n\x14GetActualJointSpeeds\x12\x16.google.protobuf.Empty\x1a\r.robotc.Joint\x12=\n\x14GetTargetJointSpeeds\x12\x16.google.protobuf.Empty\x1a\r.robotc.Joint\x12:\n\x10GetActualTcpPose\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Vector\x12:\n\x10GetTargetTcpPose\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Vector\x12;\n\x11GetActualTcpSpeed\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Vector\x12;\n\x11GetTargetTcpSpeed\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Vector\x12=\n\x13GetActualFlangePose\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.Vector\x12\x38\n\x0fGetJointTorques\x12\x16.google.protobuf.Empty\x1a\r.robotc.Joint\x12@\n\x11GetControllerTemp\x12\x16.google.protobuf.Empty\x1a\x13.robotc.Temperature\x12\x37\n\x0cGetJointTemp\x12\x12.robotc.IntRequest\x1a\x13.robotc.Temperature\x12\x39\n\x0eGetToolCurrent\x12\x16.google.protobuf.Empty\x1a\x0f.robotc.Current\x12$\n\x06SetDIO\x12\x0b.robotc.DIO\x1a\r.robotc.CmdId\x12$\n\x06GetDIO\x12\r.robotc.IOPin\x1a\x0b.robotc.DIO\x12\'\n\tSetTcpDIO\x12\x0b.robotc.DIO\x1a\r.robotc.CmdId\x12\'\n\tGetTcpDIO\x12\r.robotc.IOPin\x1a\x0b.robotc.DIO\x12$\n\x06SetAIO\x12\x0b.robotc.AIO\x1a\r.robotc.CmdId\x12$\n\x06GetAIO\x12\r.robotc.IOPin\x1a\x0b.robotc.AIO\x12(\n\nSetAInMode\x12\x0b.robotc.AIO\x1a\r.robotc.CmdId\x12(\n\nGetAInMode\x12\r.robotc.IOPin\x1a\x0b.robotc.AIO\x12)\n\x0bSetAOutMode\x12\x0b.robotc.AIO\x1a\r.robotc.CmdId\x12)\n\x0bGetAOutMode\x12\r.robotc.IOPin\x1a\x0b.robotc.AIO\x12\x31\n\x08StartSys\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x30\n\x07StopSys\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12-\n\x04Stop\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12.\n\x05\x45Stop\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x31\n\x06GetKDL\x12\x16.google.protobuf.Empty\x1a\x0f.robotc.KDParam\x12/\n\x07GetLogs\x12\x16.google.protobuf.Empty\x1a\x0c.robotc.Logs\x12\x36\n\rGetCurrentCmd\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x34\n\x10GetCmdExecStatus\x12\r.robotc.CmdId\x1a\x11.robotc.CmdStatus\x12\x34\n\x0fStartFineTuning\x12\x12.robotc.FineTuning\x1a\r.robotc.CmdId\x12\x37\n\x0eStopFineTuning\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12.\n\x05Pause\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12/\n\x06Resume\x12\x16.google.protobuf.Empty\x1a\r.robotc.CmdId\x12\x32\n\x11KinematicsForward\x12\r.robotc.Joint\x1a\x0e.robotc.Vector\x12\x32\n\x11KinematicsInverse\x12\x0e.robotc.Vector\x1a\r.robotc.Joint\x12:\n\x12\x43\x61lcTcpTranslation\x12\x14.robotc.CalcTcpParam\x1a\x0e.robotc.Vector\x12\x32\n\x08MoveLRPY\x12\x17.robotc.MoveLRPYRequest\x1a\r.robotc.CmdId\x12*\n\x06SetLED\x12\x11.robotc.LEDStatus\x1a\r.robotc.CmdId\x12.\n\x08SetVoice\x12\x13.robotc.VoiceStatus\x1a\r.robotc.CmdId\x12*\n\x06SetFan\x12\x11.robotc.FanStatus\x1a\r.robotc.CmdId\x12;\n\rGetLampStatus\x12\x16.google.protobuf.Empty\x1a\x12.robotc.LampStatus\x12\x38\n\x0bGetLuaState\x12\x16.google.protobuf.Empty\x1a\x11.robotc.LuaStatus\x12:\n\rSetExternalDO\x12\x17.robotc.ExternalDigital\x1a\x10.robotc.Response\x12=\n\rGetExternalDO\x12\x13.robotc.ExternalPin\x1a\x17.robotc.ExternalDigital\x12=\n\rGetExternalDI\x12\x13.robotc.ExternalPin\x1a\x17.robotc.ExternalDigital\x12\x39\n\rSetExternalAO\x12\x16.robotc.ExternalAnalog\x1a\x10.robotc.Response\x12<\n\rGetExternalAO\x12\x13.robotc.ExternalPin\x1a\x16.robotc.ExternalAnalog\x12<\n\rGetExternalAI\x12\x13.robotc.ExternalPin\x1a\x16.robotc.ExternalAnalog\x12=\n\x0eGetExternalIOs\x12\x16.robotc.ExternalDevice\x1a\x13.robotc.ExternalIOs\x12<\n\x0eSetExternalDOs\x12\x18.robotc.ExternalDigitals\x1a\x10.robotc.Response\x12@\n\x0eGetExternalDOs\x12\x14.robotc.ExternalPins\x1a\x18.robotc.ExternalDigitals\x12@\n\x0eGetExternalDIs\x12\x14.robotc.ExternalPins\x1a\x18.robotc.ExternalDigitals\x12;\n\x0eSetExternalAOs\x12\x17.robotc.ExternalAnalogs\x1a\x10.robotc.Response\x12?\n\x0eGetExternalAOs\x12\x14.robotc.ExternalPins\x1a\x17.robotc.ExternalAnalogs\x12?\n\x0eGetExternalAIs\x12\x14.robotc.ExternalPins\x1a\x17.robotc.ExternalAnalogs\x12\x36\n\tSetSignal\x12\x13.robotc.SignalValue\x1a\x14.robotc.SignalResult\x12\x36\n\tGetSignal\x12\x13.robotc.SignalValue\x1a\x14.robotc.SignalResult\x12\x36\n\tAddSignal\x12\x13.robotc.SignalValue\x1a\x14.robotc.SignalResult\x12>\n\x0fRegisterSignals\x12\x12.robotc.SignalList\x1a\x13.robotc.SignalValue(\x01\x30\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,messages__pb2.DESCRIPTOR,])




_SIGNALVALUE = _descriptor.Descriptor(
  name='SignalValue',
  full_name='robotc.SignalValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='robotc.SignalValue.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.SignalValue.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=122,
)


_SIGNALRESULT = _descriptor.Descriptor(
  name='SignalResult',
  full_name='robotc.SignalResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='robotc.SignalResult.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.SignalResult.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='robotc.SignalResult.ok', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=180,
)


_SIGNALLIST = _descriptor.Descriptor(
  name='SignalList',
  full_name='robotc.SignalList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='indexes', full_name='robotc.SignalList.indexes', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=211,
)


_ROBOTDATA = _descriptor.Descriptor(
  name='RobotData',
  full_name='robotc.RobotData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robotMode', full_name='robotc.RobotData.robotMode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jointModes', full_name='robotc.RobotData.jointModes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualJoint', full_name='robotc.RobotData.actualJoint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualJointSpeed', full_name='robotc.RobotData.actualJointSpeed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetJoint', full_name='robotc.RobotData.targetJoint', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetJointSpeed', full_name='robotc.RobotData.targetJointSpeed', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTcpPose', full_name='robotc.RobotData.actualTcpPose', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTcpSpeed', full_name='robotc.RobotData.actualTcpSpeed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTcpPose', full_name='robotc.RobotData.targetTcpPose', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTcpSpeed', full_name='robotc.RobotData.targetTcpSpeed', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentCmd', full_name='robotc.RobotData.currentCmd', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io', full_name='robotc.RobotData.io', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocityFactor', full_name='robotc.RobotData.velocityFactor', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clawInfo', full_name='robotc.RobotData.clawInfo', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jointTemps', full_name='robotc.RobotData.jointTemps', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='robotc.RobotData.targetTorque', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTorque', full_name='robotc.RobotData.actualTorque', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=846,
)


_ROBOTDATACMD = _descriptor.Descriptor(
  name='RobotDataCmd',
  full_name='robotc.RobotDataCmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=862,
)


_ROBOTBRIEFDATA = _descriptor.Descriptor(
  name='RobotBriefData',
  full_name='robotc.RobotBriefData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robotMode', full_name='robotc.RobotBriefData.robotMode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualJoint', full_name='robotc.RobotBriefData.actualJoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetJoint', full_name='robotc.RobotBriefData.targetJoint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTcpPose', full_name='robotc.RobotBriefData.actualTcpPose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTcpPose', full_name='robotc.RobotBriefData.targetTcpPose', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocityFactor', full_name='robotc.RobotBriefData.velocityFactor', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jointTemps', full_name='robotc.RobotBriefData.jointTemps', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=1128,
)


_ROBOTMODE = _descriptor.Descriptor(
  name='RobotMode',
  full_name='robotc.RobotMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.RobotMode.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1155,
)


_DH = _descriptor.Descriptor(
  name='DH',
  full_name='robotc.DH',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='robotc.DH.d', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='robotc.DH.a', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='robotc.DH.alpha', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='robotc.DH.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1213,
)


_KDPARAM = _descriptor.Descriptor(
  name='KDParam',
  full_name='robotc.KDParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dhParams', full_name='robotc.KDParam.dhParams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1215,
  serialized_end=1254,
)


_JOINTMODE = _descriptor.Descriptor(
  name='JointMode',
  full_name='robotc.JointMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.JointMode.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1281,
)


_AMPLITUDE = _descriptor.Descriptor(
  name='Amplitude',
  full_name='robotc.Amplitude',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='robotc.Amplitude.amplitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1313,
)


_HOLDON = _descriptor.Descriptor(
  name='HoldOn',
  full_name='robotc.HoldOn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hold_on', full_name='robotc.HoldOn.hold_on', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1340,
)


_FORCE = _descriptor.Descriptor(
  name='Force',
  full_name='robotc.Force',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='robotc.Force.force', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1364,
)


_WEIGHT = _descriptor.Descriptor(
  name='Weight',
  full_name='robotc.Weight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight', full_name='robotc.Weight.weight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1390,
)


_CLAWINFO = _descriptor.Descriptor(
  name='ClawInfo',
  full_name='robotc.ClawInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='robotc.ClawInfo.amplitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='robotc.ClawInfo.force', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='robotc.ClawInfo.weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hold_on', full_name='robotc.ClawInfo.hold_on', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1469,
)


_FORCETORQUE = _descriptor.Descriptor(
  name='ForceTorque',
  full_name='robotc.ForceTorque',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='forceTorque', full_name='robotc.ForceTorque.forceTorque', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1471,
  serialized_end=1505,
)


_JOINT = _descriptor.Descriptor(
  name='Joint',
  full_name='robotc.Joint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.Joint.joints', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1530,
)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='robotc.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='robotc.Vector.vector', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1532,
  serialized_end=1556,
)


_TEMPERATURE = _descriptor.Descriptor(
  name='Temperature',
  full_name='robotc.Temperature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='degree', full_name='robotc.Temperature.degree', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1558,
  serialized_end=1587,
)


_CURRENT = _descriptor.Descriptor(
  name='Current',
  full_name='robotc.Current',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='robotc.Current.current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=1615,
)


_FACTOR = _descriptor.Descriptor(
  name='Factor',
  full_name='robotc.Factor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.Factor.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1640,
)


_RET = _descriptor.Descriptor(
  name='Ret',
  full_name='robotc.Ret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='robotc.Ret.ret', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1660,
)


_CMDID = _descriptor.Descriptor(
  name='CmdId',
  full_name='robotc.CmdId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.CmdId.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1681,
)


_CMDSTATUS = _descriptor.Descriptor(
  name='CmdStatus',
  full_name='robotc.CmdStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.CmdStatus.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.CmdStatus.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1721,
)


_INTREQUEST = _descriptor.Descriptor(
  name='IntRequest',
  full_name='robotc.IntRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='robotc.IntRequest.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1750,
)


_LOGS = _descriptor.Descriptor(
  name='Logs',
  full_name='robotc.Logs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='robotc.Logs.log', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1784,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='robotc.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='robotc.Log.level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='robotc.Log.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='robotc.Log.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1833,
)


_SLEEPREQUEST = _descriptor.Descriptor(
  name='SleepRequest',
  full_name='robotc.SleepRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.SleepRequest.time', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=1863,
)


_SPEEDJREQUEST = _descriptor.Descriptor(
  name='SpeedJRequest',
  full_name='robotc.SpeedJRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_speed', full_name='robotc.SpeedJRequest.joint_speed', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.SpeedJRequest.acceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.SpeedJRequest.time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1865,
  serialized_end=1937,
)


_SPEEDLREQUEST = _descriptor.Descriptor(
  name='SpeedLRequest',
  full_name='robotc.SpeedLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.SpeedLRequest.velocity', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_acceleration', full_name='robotc.SpeedLRequest.position_acceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.SpeedLRequest.time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.SpeedLRequest.acceleration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1939,
  serialized_end=2039,
)


_STOPJREQUEST = _descriptor.Descriptor(
  name='StopJRequest',
  full_name='robotc.StopJRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deceleration', full_name='robotc.StopJRequest.deceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2077,
)


_STOPLREQUEST = _descriptor.Descriptor(
  name='StopLRequest',
  full_name='robotc.StopLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position_deceleration', full_name='robotc.StopLRequest.position_deceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deceleration', full_name='robotc.StopLRequest.deceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2079,
  serialized_end=2146,
)


_MOVECREQUEST = _descriptor.Descriptor(
  name='MoveCRequest',
  full_name='robotc.MoveCRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose_via', full_name='robotc.MoveCRequest.pose_via', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_to', full_name='robotc.MoveCRequest.pose_to', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_via_is_joint', full_name='robotc.MoveCRequest.pose_via_is_joint', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_to_is_joint', full_name='robotc.MoveCRequest.pose_to_is_joint', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MoveCRequest.acceleration', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MoveCRequest.velocity', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MoveCRequest.blend_radius', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.MoveCRequest.mode', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.MoveCRequest.time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_base', full_name='robotc.MoveCRequest.pose_base', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rad', full_name='robotc.MoveCRequest.rad', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2149,
  serialized_end=2385,
)


_MOVEJREQUEST = _descriptor.Descriptor(
  name='MoveJRequest',
  full_name='robotc.MoveJRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_pose_to', full_name='robotc.MoveJRequest.joint_pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.MoveJRequest.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MoveJRequest.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MoveJRequest.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.MoveJRequest.time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MoveJRequest.blend_radius', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_base', full_name='robotc.MoveJRequest.pose_base', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2388,
  serialized_end=2561,
)


_MOVELREQUEST = _descriptor.Descriptor(
  name='MoveLRequest',
  full_name='robotc.MoveLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose_to', full_name='robotc.MoveLRequest.pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.MoveLRequest.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MoveLRequest.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MoveLRequest.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.MoveLRequest.time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MoveLRequest.blend_radius', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_base', full_name='robotc.MoveLRequest.pose_base', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2564,
  serialized_end=2731,
)


_MOVELRPYREQUEST = _descriptor.Descriptor(
  name='MoveLRPYRequest',
  full_name='robotc.MoveLRPYRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose_to', full_name='robotc.MoveLRPYRequest.pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MoveLRPYRequest.acceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MoveLRPYRequest.velocity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.MoveLRPYRequest.time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MoveLRPYRequest.blend_radius', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2733,
  serialized_end=2843,
)


_MOVEPREQUEST = _descriptor.Descriptor(
  name='MovePRequest',
  full_name='robotc.MovePRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose_to', full_name='robotc.MovePRequest.pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.MovePRequest.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MovePRequest.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MovePRequest.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MovePRequest.blend_radius', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2845,
  serialized_end=2967,
)


_SERVOCREQUEST = _descriptor.Descriptor(
  name='ServoCRequest',
  full_name='robotc.ServoCRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose_to', full_name='robotc.ServoCRequest.pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.ServoCRequest.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.ServoCRequest.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.ServoCRequest.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.ServoCRequest.blend_radius', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2969,
  serialized_end=3092,
)


_SERVOJREQUEST = _descriptor.Descriptor(
  name='ServoJRequest',
  full_name='robotc.ServoJRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_pose_to', full_name='robotc.ServoJRequest.joint_pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.ServoJRequest.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.ServoJRequest.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.ServoJRequest.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.ServoJRequest.time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='look_ahead_time', full_name='robotc.ServoJRequest.look_ahead_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain', full_name='robotc.ServoJRequest.gain', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3095,
  serialized_end=3255,
)


_FINETUNING = _descriptor.Descriptor(
  name='FineTuning',
  full_name='robotc.FineTuning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.FineTuning.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='robotc.FineTuning.base', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='robotc.FineTuning.coordinate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='robotc.FineTuning.target', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='robotc.FineTuning.direction', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3257,
  serialized_end=3352,
)


_LEDSTATUS = _descriptor.Descriptor(
  name='LEDStatus',
  full_name='robotc.LEDStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.LEDStatus.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='robotc.LEDStatus.speed', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='robotc.LEDStatus.color', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3354,
  serialized_end=3409,
)


_VOICESTATUS = _descriptor.Descriptor(
  name='VoiceStatus',
  full_name='robotc.VoiceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice', full_name='robotc.VoiceStatus.voice', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='robotc.VoiceStatus.volume', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3411,
  serialized_end=3455,
)


_FANSTATUS = _descriptor.Descriptor(
  name='FanStatus',
  full_name='robotc.FanStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fan', full_name='robotc.FanStatus.fan', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3457,
  serialized_end=3481,
)


_CALCTCPPARAM = _descriptor.Descriptor(
  name='CalcTcpParam',
  full_name='robotc.CalcTcpParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='robotc.CalcTcpParam.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tol', full_name='robotc.CalcTcpParam.tol', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3483,
  serialized_end=3541,
)


_LUASTATUS = _descriptor.Descriptor(
  name='LuaStatus',
  full_name='robotc.LuaStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='robotc.LuaStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_pose', full_name='robotc.LuaStatus.last_pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_joints', full_name='robotc.LuaStatus.last_joints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3543,
  serialized_end=3654,
)


_LAMPSTATUS = _descriptor.Descriptor(
  name='LampStatus',
  full_name='robotc.LampStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='led', full_name='robotc.LampStatus.led', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='robotc.LampStatus.voice', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fan', full_name='robotc.LampStatus.fan', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3656,
  serialized_end=3768,
)


_PVATREQUEST = _descriptor.Descriptor(
  name='PVATRequest',
  full_name='robotc.PVATRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='robotc.PVATRequest.duration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q', full_name='robotc.PVATRequest.q', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='robotc.PVATRequest.v', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='robotc.PVATRequest.acc', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3770,
  serialized_end=3836,
)


_EXTERNALPIN = _descriptor.Descriptor(
  name='ExternalPin',
  full_name='robotc.ExternalPin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalPin.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalPin.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3838,
  serialized_end=3876,
)


_EXTERNALPINS = _descriptor.Descriptor(
  name='ExternalPins',
  full_name='robotc.ExternalPins',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalPins.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalPins.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='robotc.ExternalPins.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3878,
  serialized_end=3933,
)


_EXTERNALDIGITAL = _descriptor.Descriptor(
  name='ExternalDigital',
  full_name='robotc.ExternalDigital',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalDigital.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalDigital.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.ExternalDigital.value', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3935,
  serialized_end=3992,
)


_EXTERNALDIGITALS = _descriptor.Descriptor(
  name='ExternalDigitals',
  full_name='robotc.ExternalDigitals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalDigitals.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalDigitals.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='robotc.ExternalDigitals.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='robotc.ExternalDigitals.values', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3994,
  serialized_end=4069,
)


_EXTERNALANALOG = _descriptor.Descriptor(
  name='ExternalAnalog',
  full_name='robotc.ExternalAnalog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalAnalog.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalAnalog.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.ExternalAnalog.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4071,
  serialized_end=4127,
)


_EXTERNALANALOGS = _descriptor.Descriptor(
  name='ExternalAnalogs',
  full_name='robotc.ExternalAnalogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalAnalogs.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ExternalAnalogs.pin', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='robotc.ExternalAnalogs.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='robotc.ExternalAnalogs.values', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4129,
  serialized_end=4203,
)


_EXTERNALDEVICE = _descriptor.Descriptor(
  name='ExternalDevice',
  full_name='robotc.ExternalDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ExternalDevice.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4205,
  serialized_end=4233,
)


_EXTERNALIOS = _descriptor.Descriptor(
  name='ExternalIOs',
  full_name='robotc.ExternalIOs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dis', full_name='robotc.ExternalIOs.dis', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dos', full_name='robotc.ExternalIOs.dos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ais', full_name='robotc.ExternalIOs.ais', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos', full_name='robotc.ExternalIOs.aos', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4236,
  serialized_end=4399,
)

_ROBOTDATA.fields_by_name['robotMode'].message_type = _ROBOTMODE
_ROBOTDATA.fields_by_name['jointModes'].message_type = _JOINTMODE
_ROBOTDATA.fields_by_name['actualJoint'].message_type = _JOINT
_ROBOTDATA.fields_by_name['actualJointSpeed'].message_type = _JOINT
_ROBOTDATA.fields_by_name['targetJoint'].message_type = _JOINT
_ROBOTDATA.fields_by_name['targetJointSpeed'].message_type = _JOINT
_ROBOTDATA.fields_by_name['actualTcpPose'].message_type = _VECTOR
_ROBOTDATA.fields_by_name['actualTcpSpeed'].message_type = _VECTOR
_ROBOTDATA.fields_by_name['targetTcpPose'].message_type = _VECTOR
_ROBOTDATA.fields_by_name['targetTcpSpeed'].message_type = _VECTOR
_ROBOTDATA.fields_by_name['currentCmd'].message_type = _CMDSTATUS
_ROBOTDATA.fields_by_name['io'].message_type = messages__pb2._IO
_ROBOTDATA.fields_by_name['clawInfo'].message_type = _CLAWINFO
_ROBOTDATA.fields_by_name['jointTemps'].message_type = _JOINT
_ROBOTDATA.fields_by_name['targetTorque'].message_type = _JOINT
_ROBOTDATA.fields_by_name['actualTorque'].message_type = _JOINT
_ROBOTBRIEFDATA.fields_by_name['robotMode'].message_type = _ROBOTMODE
_ROBOTBRIEFDATA.fields_by_name['actualJoint'].message_type = _JOINT
_ROBOTBRIEFDATA.fields_by_name['targetJoint'].message_type = _JOINT
_ROBOTBRIEFDATA.fields_by_name['actualTcpPose'].message_type = _VECTOR
_ROBOTBRIEFDATA.fields_by_name['targetTcpPose'].message_type = _VECTOR
_ROBOTBRIEFDATA.fields_by_name['jointTemps'].message_type = _JOINT
_KDPARAM.fields_by_name['dhParams'].message_type = _DH
_LOGS.fields_by_name['log'].message_type = _LOG
_MOVECREQUEST.fields_by_name['pose_base'].message_type = messages__pb2._PR
_MOVEJREQUEST.fields_by_name['pose_base'].message_type = messages__pb2._PR
_MOVELREQUEST.fields_by_name['pose_base'].message_type = messages__pb2._PR
_CALCTCPPARAM.fields_by_name['poses'].message_type = _VECTOR
_LUASTATUS.fields_by_name['state'].enum_type = messages__pb2._LUASTATE
_LUASTATUS.fields_by_name['last_pose'].message_type = messages__pb2._PR
_LUASTATUS.fields_by_name['last_joints'].message_type = messages__pb2._JPOSE
_LAMPSTATUS.fields_by_name['led'].message_type = _LEDSTATUS
_LAMPSTATUS.fields_by_name['voice'].message_type = _VOICESTATUS
_LAMPSTATUS.fields_by_name['fan'].message_type = _FANSTATUS
_EXTERNALIOS.fields_by_name['dis'].message_type = _EXTERNALDIGITAL
_EXTERNALIOS.fields_by_name['dos'].message_type = _EXTERNALDIGITAL
_EXTERNALIOS.fields_by_name['ais'].message_type = _EXTERNALANALOG
_EXTERNALIOS.fields_by_name['aos'].message_type = _EXTERNALANALOG
DESCRIPTOR.message_types_by_name['SignalValue'] = _SIGNALVALUE
DESCRIPTOR.message_types_by_name['SignalResult'] = _SIGNALRESULT
DESCRIPTOR.message_types_by_name['SignalList'] = _SIGNALLIST
DESCRIPTOR.message_types_by_name['RobotData'] = _ROBOTDATA
DESCRIPTOR.message_types_by_name['RobotDataCmd'] = _ROBOTDATACMD
DESCRIPTOR.message_types_by_name['RobotBriefData'] = _ROBOTBRIEFDATA
DESCRIPTOR.message_types_by_name['RobotMode'] = _ROBOTMODE
DESCRIPTOR.message_types_by_name['DH'] = _DH
DESCRIPTOR.message_types_by_name['KDParam'] = _KDPARAM
DESCRIPTOR.message_types_by_name['JointMode'] = _JOINTMODE
DESCRIPTOR.message_types_by_name['Amplitude'] = _AMPLITUDE
DESCRIPTOR.message_types_by_name['HoldOn'] = _HOLDON
DESCRIPTOR.message_types_by_name['Force'] = _FORCE
DESCRIPTOR.message_types_by_name['Weight'] = _WEIGHT
DESCRIPTOR.message_types_by_name['ClawInfo'] = _CLAWINFO
DESCRIPTOR.message_types_by_name['ForceTorque'] = _FORCETORQUE
DESCRIPTOR.message_types_by_name['Joint'] = _JOINT
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['Temperature'] = _TEMPERATURE
DESCRIPTOR.message_types_by_name['Current'] = _CURRENT
DESCRIPTOR.message_types_by_name['Factor'] = _FACTOR
DESCRIPTOR.message_types_by_name['Ret'] = _RET
DESCRIPTOR.message_types_by_name['CmdId'] = _CMDID
DESCRIPTOR.message_types_by_name['CmdStatus'] = _CMDSTATUS
DESCRIPTOR.message_types_by_name['IntRequest'] = _INTREQUEST
DESCRIPTOR.message_types_by_name['Logs'] = _LOGS
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['SleepRequest'] = _SLEEPREQUEST
DESCRIPTOR.message_types_by_name['SpeedJRequest'] = _SPEEDJREQUEST
DESCRIPTOR.message_types_by_name['SpeedLRequest'] = _SPEEDLREQUEST
DESCRIPTOR.message_types_by_name['StopJRequest'] = _STOPJREQUEST
DESCRIPTOR.message_types_by_name['StopLRequest'] = _STOPLREQUEST
DESCRIPTOR.message_types_by_name['MoveCRequest'] = _MOVECREQUEST
DESCRIPTOR.message_types_by_name['MoveJRequest'] = _MOVEJREQUEST
DESCRIPTOR.message_types_by_name['MoveLRequest'] = _MOVELREQUEST
DESCRIPTOR.message_types_by_name['MoveLRPYRequest'] = _MOVELRPYREQUEST
DESCRIPTOR.message_types_by_name['MovePRequest'] = _MOVEPREQUEST
DESCRIPTOR.message_types_by_name['ServoCRequest'] = _SERVOCREQUEST
DESCRIPTOR.message_types_by_name['ServoJRequest'] = _SERVOJREQUEST
DESCRIPTOR.message_types_by_name['FineTuning'] = _FINETUNING
DESCRIPTOR.message_types_by_name['LEDStatus'] = _LEDSTATUS
DESCRIPTOR.message_types_by_name['VoiceStatus'] = _VOICESTATUS
DESCRIPTOR.message_types_by_name['FanStatus'] = _FANSTATUS
DESCRIPTOR.message_types_by_name['CalcTcpParam'] = _CALCTCPPARAM
DESCRIPTOR.message_types_by_name['LuaStatus'] = _LUASTATUS
DESCRIPTOR.message_types_by_name['LampStatus'] = _LAMPSTATUS
DESCRIPTOR.message_types_by_name['PVATRequest'] = _PVATREQUEST
DESCRIPTOR.message_types_by_name['ExternalPin'] = _EXTERNALPIN
DESCRIPTOR.message_types_by_name['ExternalPins'] = _EXTERNALPINS
DESCRIPTOR.message_types_by_name['ExternalDigital'] = _EXTERNALDIGITAL
DESCRIPTOR.message_types_by_name['ExternalDigitals'] = _EXTERNALDIGITALS
DESCRIPTOR.message_types_by_name['ExternalAnalog'] = _EXTERNALANALOG
DESCRIPTOR.message_types_by_name['ExternalAnalogs'] = _EXTERNALANALOGS
DESCRIPTOR.message_types_by_name['ExternalDevice'] = _EXTERNALDEVICE
DESCRIPTOR.message_types_by_name['ExternalIOs'] = _EXTERNALIOS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignalValue = _reflection.GeneratedProtocolMessageType('SignalValue', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALVALUE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SignalValue)
  })
_sym_db.RegisterMessage(SignalValue)

SignalResult = _reflection.GeneratedProtocolMessageType('SignalResult', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALRESULT,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SignalResult)
  })
_sym_db.RegisterMessage(SignalResult)

SignalList = _reflection.GeneratedProtocolMessageType('SignalList', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALLIST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SignalList)
  })
_sym_db.RegisterMessage(SignalList)

RobotData = _reflection.GeneratedProtocolMessageType('RobotData', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTDATA,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotData)
  })
_sym_db.RegisterMessage(RobotData)

RobotDataCmd = _reflection.GeneratedProtocolMessageType('RobotDataCmd', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTDATACMD,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotDataCmd)
  })
_sym_db.RegisterMessage(RobotDataCmd)

RobotBriefData = _reflection.GeneratedProtocolMessageType('RobotBriefData', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTBRIEFDATA,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotBriefData)
  })
_sym_db.RegisterMessage(RobotBriefData)

RobotMode = _reflection.GeneratedProtocolMessageType('RobotMode', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTMODE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotMode)
  })
_sym_db.RegisterMessage(RobotMode)

DH = _reflection.GeneratedProtocolMessageType('DH', (_message.Message,), {
  'DESCRIPTOR' : _DH,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DH)
  })
_sym_db.RegisterMessage(DH)

KDParam = _reflection.GeneratedProtocolMessageType('KDParam', (_message.Message,), {
  'DESCRIPTOR' : _KDPARAM,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.KDParam)
  })
_sym_db.RegisterMessage(KDParam)

JointMode = _reflection.GeneratedProtocolMessageType('JointMode', (_message.Message,), {
  'DESCRIPTOR' : _JOINTMODE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointMode)
  })
_sym_db.RegisterMessage(JointMode)

Amplitude = _reflection.GeneratedProtocolMessageType('Amplitude', (_message.Message,), {
  'DESCRIPTOR' : _AMPLITUDE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Amplitude)
  })
_sym_db.RegisterMessage(Amplitude)

HoldOn = _reflection.GeneratedProtocolMessageType('HoldOn', (_message.Message,), {
  'DESCRIPTOR' : _HOLDON,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.HoldOn)
  })
_sym_db.RegisterMessage(HoldOn)

Force = _reflection.GeneratedProtocolMessageType('Force', (_message.Message,), {
  'DESCRIPTOR' : _FORCE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Force)
  })
_sym_db.RegisterMessage(Force)

Weight = _reflection.GeneratedProtocolMessageType('Weight', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHT,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Weight)
  })
_sym_db.RegisterMessage(Weight)

ClawInfo = _reflection.GeneratedProtocolMessageType('ClawInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLAWINFO,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ClawInfo)
  })
_sym_db.RegisterMessage(ClawInfo)

ForceTorque = _reflection.GeneratedProtocolMessageType('ForceTorque', (_message.Message,), {
  'DESCRIPTOR' : _FORCETORQUE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ForceTorque)
  })
_sym_db.RegisterMessage(ForceTorque)

Joint = _reflection.GeneratedProtocolMessageType('Joint', (_message.Message,), {
  'DESCRIPTOR' : _JOINT,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Joint)
  })
_sym_db.RegisterMessage(Joint)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Vector)
  })
_sym_db.RegisterMessage(Vector)

Temperature = _reflection.GeneratedProtocolMessageType('Temperature', (_message.Message,), {
  'DESCRIPTOR' : _TEMPERATURE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Temperature)
  })
_sym_db.RegisterMessage(Temperature)

Current = _reflection.GeneratedProtocolMessageType('Current', (_message.Message,), {
  'DESCRIPTOR' : _CURRENT,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Current)
  })
_sym_db.RegisterMessage(Current)

Factor = _reflection.GeneratedProtocolMessageType('Factor', (_message.Message,), {
  'DESCRIPTOR' : _FACTOR,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Factor)
  })
_sym_db.RegisterMessage(Factor)

Ret = _reflection.GeneratedProtocolMessageType('Ret', (_message.Message,), {
  'DESCRIPTOR' : _RET,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Ret)
  })
_sym_db.RegisterMessage(Ret)

CmdId = _reflection.GeneratedProtocolMessageType('CmdId', (_message.Message,), {
  'DESCRIPTOR' : _CMDID,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CmdId)
  })
_sym_db.RegisterMessage(CmdId)

CmdStatus = _reflection.GeneratedProtocolMessageType('CmdStatus', (_message.Message,), {
  'DESCRIPTOR' : _CMDSTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CmdStatus)
  })
_sym_db.RegisterMessage(CmdStatus)

IntRequest = _reflection.GeneratedProtocolMessageType('IntRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.IntRequest)
  })
_sym_db.RegisterMessage(IntRequest)

Logs = _reflection.GeneratedProtocolMessageType('Logs', (_message.Message,), {
  'DESCRIPTOR' : _LOGS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Logs)
  })
_sym_db.RegisterMessage(Logs)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Log)
  })
_sym_db.RegisterMessage(Log)

SleepRequest = _reflection.GeneratedProtocolMessageType('SleepRequest', (_message.Message,), {
  'DESCRIPTOR' : _SLEEPREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SleepRequest)
  })
_sym_db.RegisterMessage(SleepRequest)

SpeedJRequest = _reflection.GeneratedProtocolMessageType('SpeedJRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDJREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SpeedJRequest)
  })
_sym_db.RegisterMessage(SpeedJRequest)

SpeedLRequest = _reflection.GeneratedProtocolMessageType('SpeedLRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDLREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SpeedLRequest)
  })
_sym_db.RegisterMessage(SpeedLRequest)

StopJRequest = _reflection.GeneratedProtocolMessageType('StopJRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPJREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.StopJRequest)
  })
_sym_db.RegisterMessage(StopJRequest)

StopLRequest = _reflection.GeneratedProtocolMessageType('StopLRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPLREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.StopLRequest)
  })
_sym_db.RegisterMessage(StopLRequest)

MoveCRequest = _reflection.GeneratedProtocolMessageType('MoveCRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVECREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveCRequest)
  })
_sym_db.RegisterMessage(MoveCRequest)

MoveJRequest = _reflection.GeneratedProtocolMessageType('MoveJRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEJREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveJRequest)
  })
_sym_db.RegisterMessage(MoveJRequest)

MoveLRequest = _reflection.GeneratedProtocolMessageType('MoveLRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVELREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveLRequest)
  })
_sym_db.RegisterMessage(MoveLRequest)

MoveLRPYRequest = _reflection.GeneratedProtocolMessageType('MoveLRPYRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVELRPYREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveLRPYRequest)
  })
_sym_db.RegisterMessage(MoveLRPYRequest)

MovePRequest = _reflection.GeneratedProtocolMessageType('MovePRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEPREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MovePRequest)
  })
_sym_db.RegisterMessage(MovePRequest)

ServoCRequest = _reflection.GeneratedProtocolMessageType('ServoCRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVOCREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ServoCRequest)
  })
_sym_db.RegisterMessage(ServoCRequest)

ServoJRequest = _reflection.GeneratedProtocolMessageType('ServoJRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVOJREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ServoJRequest)
  })
_sym_db.RegisterMessage(ServoJRequest)

FineTuning = _reflection.GeneratedProtocolMessageType('FineTuning', (_message.Message,), {
  'DESCRIPTOR' : _FINETUNING,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.FineTuning)
  })
_sym_db.RegisterMessage(FineTuning)

LEDStatus = _reflection.GeneratedProtocolMessageType('LEDStatus', (_message.Message,), {
  'DESCRIPTOR' : _LEDSTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LEDStatus)
  })
_sym_db.RegisterMessage(LEDStatus)

VoiceStatus = _reflection.GeneratedProtocolMessageType('VoiceStatus', (_message.Message,), {
  'DESCRIPTOR' : _VOICESTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.VoiceStatus)
  })
_sym_db.RegisterMessage(VoiceStatus)

FanStatus = _reflection.GeneratedProtocolMessageType('FanStatus', (_message.Message,), {
  'DESCRIPTOR' : _FANSTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.FanStatus)
  })
_sym_db.RegisterMessage(FanStatus)

CalcTcpParam = _reflection.GeneratedProtocolMessageType('CalcTcpParam', (_message.Message,), {
  'DESCRIPTOR' : _CALCTCPPARAM,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CalcTcpParam)
  })
_sym_db.RegisterMessage(CalcTcpParam)

LuaStatus = _reflection.GeneratedProtocolMessageType('LuaStatus', (_message.Message,), {
  'DESCRIPTOR' : _LUASTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LuaStatus)
  })
_sym_db.RegisterMessage(LuaStatus)

LampStatus = _reflection.GeneratedProtocolMessageType('LampStatus', (_message.Message,), {
  'DESCRIPTOR' : _LAMPSTATUS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LampStatus)
  })
_sym_db.RegisterMessage(LampStatus)

PVATRequest = _reflection.GeneratedProtocolMessageType('PVATRequest', (_message.Message,), {
  'DESCRIPTOR' : _PVATREQUEST,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.PVATRequest)
  })
_sym_db.RegisterMessage(PVATRequest)

ExternalPin = _reflection.GeneratedProtocolMessageType('ExternalPin', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALPIN,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalPin)
  })
_sym_db.RegisterMessage(ExternalPin)

ExternalPins = _reflection.GeneratedProtocolMessageType('ExternalPins', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALPINS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalPins)
  })
_sym_db.RegisterMessage(ExternalPins)

ExternalDigital = _reflection.GeneratedProtocolMessageType('ExternalDigital', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALDIGITAL,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalDigital)
  })
_sym_db.RegisterMessage(ExternalDigital)

ExternalDigitals = _reflection.GeneratedProtocolMessageType('ExternalDigitals', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALDIGITALS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalDigitals)
  })
_sym_db.RegisterMessage(ExternalDigitals)

ExternalAnalog = _reflection.GeneratedProtocolMessageType('ExternalAnalog', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALANALOG,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalAnalog)
  })
_sym_db.RegisterMessage(ExternalAnalog)

ExternalAnalogs = _reflection.GeneratedProtocolMessageType('ExternalAnalogs', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALANALOGS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalAnalogs)
  })
_sym_db.RegisterMessage(ExternalAnalogs)

ExternalDevice = _reflection.GeneratedProtocolMessageType('ExternalDevice', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALDEVICE,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalDevice)
  })
_sym_db.RegisterMessage(ExternalDevice)

ExternalIOs = _reflection.GeneratedProtocolMessageType('ExternalIOs', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIOS,
  '__module__' : 'robot_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExternalIOs)
  })
_sym_db.RegisterMessage(ExternalIOs)



_ROBOTCONTROLLER = _descriptor.ServiceDescriptor(
  name='RobotController',
  full_name='robotc.RobotController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4402,
  serialized_end=10240,
  methods=[
  _descriptor.MethodDescriptor(
    name='PowerDown',
    full_name='robotc.RobotController.PowerDown',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Sleep',
    full_name='robotc.RobotController.Sleep',
    index=1,
    containing_service=None,
    input_type=_SLEEPREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Sync',
    full_name='robotc.RobotController.Sync',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TeachMode',
    full_name='robotc.RobotController.TeachMode',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndTeachMode',
    full_name='robotc.RobotController.EndTeachMode',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVelocityFactor',
    full_name='robotc.RobotController.SetVelocityFactor',
    index=5,
    containing_service=None,
    input_type=_FACTOR,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVelocityFactor',
    full_name='robotc.RobotController.GetVelocityFactor',
    index=6,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_FACTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetGravity',
    full_name='robotc.RobotController.SetGravity',
    index=7,
    containing_service=None,
    input_type=messages__pb2._COORDINATE,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGravity',
    full_name='robotc.RobotController.GetGravity',
    index=8,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._COORDINATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPayload',
    full_name='robotc.RobotController.SetPayload',
    index=9,
    containing_service=None,
    input_type=messages__pb2._PAYLOAD,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPayload',
    full_name='robotc.RobotController.GetPayload',
    index=10,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._PAYLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPayloadMass',
    full_name='robotc.RobotController.SetPayloadMass',
    index=11,
    containing_service=None,
    input_type=messages__pb2._PAYLOADMASS,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPayloadMass',
    full_name='robotc.RobotController.GetPayloadMass',
    index=12,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._PAYLOADMASS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPayloadCog',
    full_name='robotc.RobotController.SetPayloadCog',
    index=13,
    containing_service=None,
    input_type=messages__pb2._PAYLOADCOG,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPayloadCog',
    full_name='robotc.RobotController.GetPayloadCog',
    index=14,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._PAYLOADCOG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTcp',
    full_name='robotc.RobotController.SetTcp',
    index=15,
    containing_service=None,
    input_type=messages__pb2._PR,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTcp',
    full_name='robotc.RobotController.GetTcp',
    index=16,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._PR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetClawAmplitude',
    full_name='robotc.RobotController.SetClawAmplitude',
    index=17,
    containing_service=None,
    input_type=_AMPLITUDE,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClawAmplitude',
    full_name='robotc.RobotController.GetClawAmplitude',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_AMPLITUDE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClawHoldOn',
    full_name='robotc.RobotController.GetClawHoldOn',
    index=19,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HOLDON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetClawForce',
    full_name='robotc.RobotController.SetClawForce',
    index=20,
    containing_service=None,
    input_type=_FORCE,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClawWeight',
    full_name='robotc.RobotController.GetClawWeight',
    index=21,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_WEIGHT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTcpForce',
    full_name='robotc.RobotController.GetTcpForce',
    index=22,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_FORCETORQUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetClaw',
    full_name='robotc.RobotController.SetClaw',
    index=23,
    containing_service=None,
    input_type=_CLAWINFO,
    output_type=_CLAWINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClaw',
    full_name='robotc.RobotController.GetClaw',
    index=24,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CLAWINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPos',
    full_name='robotc.RobotController.SetPos',
    index=25,
    containing_service=None,
    input_type=messages__pb2._JPOSE,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpeedJ',
    full_name='robotc.RobotController.SpeedJ',
    index=26,
    containing_service=None,
    input_type=_SPEEDJREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpeedL',
    full_name='robotc.RobotController.SpeedL',
    index=27,
    containing_service=None,
    input_type=_SPEEDLREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopJ',
    full_name='robotc.RobotController.StopJ',
    index=28,
    containing_service=None,
    input_type=_STOPJREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopL',
    full_name='robotc.RobotController.StopL',
    index=29,
    containing_service=None,
    input_type=_STOPLREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopMove',
    full_name='robotc.RobotController.StopMove',
    index=30,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveC',
    full_name='robotc.RobotController.MoveC',
    index=31,
    containing_service=None,
    input_type=_MOVECREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveJ',
    full_name='robotc.RobotController.MoveJ',
    index=32,
    containing_service=None,
    input_type=_MOVEJREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveL',
    full_name='robotc.RobotController.MoveL',
    index=33,
    containing_service=None,
    input_type=_MOVELREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveLJ',
    full_name='robotc.RobotController.MoveLJ',
    index=34,
    containing_service=None,
    input_type=_MOVELREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveP',
    full_name='robotc.RobotController.MoveP',
    index=35,
    containing_service=None,
    input_type=_MOVEPREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePT',
    full_name='robotc.RobotController.MovePT',
    index=36,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePTStream',
    full_name='robotc.RobotController.MovePTStream',
    index=37,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePVT',
    full_name='robotc.RobotController.MovePVT',
    index=38,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePVTStream',
    full_name='robotc.RobotController.MovePVTStream',
    index=39,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePVAT',
    full_name='robotc.RobotController.MovePVAT',
    index=40,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MovePVATStream',
    full_name='robotc.RobotController.MovePVATStream',
    index=41,
    containing_service=None,
    input_type=_PVATREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServoC',
    full_name='robotc.RobotController.ServoC',
    index=42,
    containing_service=None,
    input_type=_SERVOCREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServoJ',
    full_name='robotc.RobotController.ServoJ',
    index=43,
    containing_service=None,
    input_type=_SERVOJREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotData',
    full_name='robotc.RobotController.GetRobotData',
    index=44,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ROBOTDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotBriefData',
    full_name='robotc.RobotController.GetRobotBriefData',
    index=45,
    containing_service=None,
    input_type=_ROBOTDATACMD,
    output_type=_ROBOTBRIEFDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotIOData',
    full_name='robotc.RobotController.GetRobotIOData',
    index=46,
    containing_service=None,
    input_type=_ROBOTDATACMD,
    output_type=messages__pb2._IO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotMode',
    full_name='robotc.RobotController.GetRobotMode',
    index=47,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ROBOTMODE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActualJointPositions',
    full_name='robotc.RobotController.GetActualJointPositions',
    index=48,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetJointPositions',
    full_name='robotc.RobotController.GetTargetJointPositions',
    index=49,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActualJointSpeeds',
    full_name='robotc.RobotController.GetActualJointSpeeds',
    index=50,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetJointSpeeds',
    full_name='robotc.RobotController.GetTargetJointSpeeds',
    index=51,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActualTcpPose',
    full_name='robotc.RobotController.GetActualTcpPose',
    index=52,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetTcpPose',
    full_name='robotc.RobotController.GetTargetTcpPose',
    index=53,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActualTcpSpeed',
    full_name='robotc.RobotController.GetActualTcpSpeed',
    index=54,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetTcpSpeed',
    full_name='robotc.RobotController.GetTargetTcpSpeed',
    index=55,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActualFlangePose',
    full_name='robotc.RobotController.GetActualFlangePose',
    index=56,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJointTorques',
    full_name='robotc.RobotController.GetJointTorques',
    index=57,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControllerTemp',
    full_name='robotc.RobotController.GetControllerTemp',
    index=58,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_TEMPERATURE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJointTemp',
    full_name='robotc.RobotController.GetJointTemp',
    index=59,
    containing_service=None,
    input_type=_INTREQUEST,
    output_type=_TEMPERATURE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetToolCurrent',
    full_name='robotc.RobotController.GetToolCurrent',
    index=60,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CURRENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDIO',
    full_name='robotc.RobotController.SetDIO',
    index=61,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDIO',
    full_name='robotc.RobotController.GetDIO',
    index=62,
    containing_service=None,
    input_type=messages__pb2._IOPIN,
    output_type=messages__pb2._DIO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTcpDIO',
    full_name='robotc.RobotController.SetTcpDIO',
    index=63,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTcpDIO',
    full_name='robotc.RobotController.GetTcpDIO',
    index=64,
    containing_service=None,
    input_type=messages__pb2._IOPIN,
    output_type=messages__pb2._DIO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAIO',
    full_name='robotc.RobotController.SetAIO',
    index=65,
    containing_service=None,
    input_type=messages__pb2._AIO,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAIO',
    full_name='robotc.RobotController.GetAIO',
    index=66,
    containing_service=None,
    input_type=messages__pb2._IOPIN,
    output_type=messages__pb2._AIO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAInMode',
    full_name='robotc.RobotController.SetAInMode',
    index=67,
    containing_service=None,
    input_type=messages__pb2._AIO,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAInMode',
    full_name='robotc.RobotController.GetAInMode',
    index=68,
    containing_service=None,
    input_type=messages__pb2._IOPIN,
    output_type=messages__pb2._AIO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAOutMode',
    full_name='robotc.RobotController.SetAOutMode',
    index=69,
    containing_service=None,
    input_type=messages__pb2._AIO,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAOutMode',
    full_name='robotc.RobotController.GetAOutMode',
    index=70,
    containing_service=None,
    input_type=messages__pb2._IOPIN,
    output_type=messages__pb2._AIO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartSys',
    full_name='robotc.RobotController.StartSys',
    index=71,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopSys',
    full_name='robotc.RobotController.StopSys',
    index=72,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='robotc.RobotController.Stop',
    index=73,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EStop',
    full_name='robotc.RobotController.EStop',
    index=74,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetKDL',
    full_name='robotc.RobotController.GetKDL',
    index=75,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_KDPARAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogs',
    full_name='robotc.RobotController.GetLogs',
    index=76,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LOGS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurrentCmd',
    full_name='robotc.RobotController.GetCurrentCmd',
    index=77,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCmdExecStatus',
    full_name='robotc.RobotController.GetCmdExecStatus',
    index=78,
    containing_service=None,
    input_type=_CMDID,
    output_type=_CMDSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartFineTuning',
    full_name='robotc.RobotController.StartFineTuning',
    index=79,
    containing_service=None,
    input_type=_FINETUNING,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopFineTuning',
    full_name='robotc.RobotController.StopFineTuning',
    index=80,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Pause',
    full_name='robotc.RobotController.Pause',
    index=81,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Resume',
    full_name='robotc.RobotController.Resume',
    index=82,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KinematicsForward',
    full_name='robotc.RobotController.KinematicsForward',
    index=83,
    containing_service=None,
    input_type=_JOINT,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KinematicsInverse',
    full_name='robotc.RobotController.KinematicsInverse',
    index=84,
    containing_service=None,
    input_type=_VECTOR,
    output_type=_JOINT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CalcTcpTranslation',
    full_name='robotc.RobotController.CalcTcpTranslation',
    index=85,
    containing_service=None,
    input_type=_CALCTCPPARAM,
    output_type=_VECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveLRPY',
    full_name='robotc.RobotController.MoveLRPY',
    index=86,
    containing_service=None,
    input_type=_MOVELRPYREQUEST,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLED',
    full_name='robotc.RobotController.SetLED',
    index=87,
    containing_service=None,
    input_type=_LEDSTATUS,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVoice',
    full_name='robotc.RobotController.SetVoice',
    index=88,
    containing_service=None,
    input_type=_VOICESTATUS,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFan',
    full_name='robotc.RobotController.SetFan',
    index=89,
    containing_service=None,
    input_type=_FANSTATUS,
    output_type=_CMDID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLampStatus',
    full_name='robotc.RobotController.GetLampStatus',
    index=90,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LAMPSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLuaState',
    full_name='robotc.RobotController.GetLuaState',
    index=91,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LUASTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExternalDO',
    full_name='robotc.RobotController.SetExternalDO',
    index=92,
    containing_service=None,
    input_type=_EXTERNALDIGITAL,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalDO',
    full_name='robotc.RobotController.GetExternalDO',
    index=93,
    containing_service=None,
    input_type=_EXTERNALPIN,
    output_type=_EXTERNALDIGITAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalDI',
    full_name='robotc.RobotController.GetExternalDI',
    index=94,
    containing_service=None,
    input_type=_EXTERNALPIN,
    output_type=_EXTERNALDIGITAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExternalAO',
    full_name='robotc.RobotController.SetExternalAO',
    index=95,
    containing_service=None,
    input_type=_EXTERNALANALOG,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalAO',
    full_name='robotc.RobotController.GetExternalAO',
    index=96,
    containing_service=None,
    input_type=_EXTERNALPIN,
    output_type=_EXTERNALANALOG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalAI',
    full_name='robotc.RobotController.GetExternalAI',
    index=97,
    containing_service=None,
    input_type=_EXTERNALPIN,
    output_type=_EXTERNALANALOG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalIOs',
    full_name='robotc.RobotController.GetExternalIOs',
    index=98,
    containing_service=None,
    input_type=_EXTERNALDEVICE,
    output_type=_EXTERNALIOS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExternalDOs',
    full_name='robotc.RobotController.SetExternalDOs',
    index=99,
    containing_service=None,
    input_type=_EXTERNALDIGITALS,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalDOs',
    full_name='robotc.RobotController.GetExternalDOs',
    index=100,
    containing_service=None,
    input_type=_EXTERNALPINS,
    output_type=_EXTERNALDIGITALS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalDIs',
    full_name='robotc.RobotController.GetExternalDIs',
    index=101,
    containing_service=None,
    input_type=_EXTERNALPINS,
    output_type=_EXTERNALDIGITALS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExternalAOs',
    full_name='robotc.RobotController.SetExternalAOs',
    index=102,
    containing_service=None,
    input_type=_EXTERNALANALOGS,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalAOs',
    full_name='robotc.RobotController.GetExternalAOs',
    index=103,
    containing_service=None,
    input_type=_EXTERNALPINS,
    output_type=_EXTERNALANALOGS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExternalAIs',
    full_name='robotc.RobotController.GetExternalAIs',
    index=104,
    containing_service=None,
    input_type=_EXTERNALPINS,
    output_type=_EXTERNALANALOGS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSignal',
    full_name='robotc.RobotController.SetSignal',
    index=105,
    containing_service=None,
    input_type=_SIGNALVALUE,
    output_type=_SIGNALRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignal',
    full_name='robotc.RobotController.GetSignal',
    index=106,
    containing_service=None,
    input_type=_SIGNALVALUE,
    output_type=_SIGNALRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddSignal',
    full_name='robotc.RobotController.AddSignal',
    index=107,
    containing_service=None,
    input_type=_SIGNALVALUE,
    output_type=_SIGNALRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterSignals',
    full_name='robotc.RobotController.RegisterSignals',
    index=108,
    containing_service=None,
    input_type=_SIGNALLIST,
    output_type=_SIGNALVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROBOTCONTROLLER)

DESCRIPTOR.services_by_name['RobotController'] = _ROBOTCONTROLLER

# @@protoc_insertion_point(module_scope)
